@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2024 openpyxl
 
 """Workbook is the top-level container for all document information."""
 from copy import copy
@@ -29,8 +29,9 @@ from openpyxl.styles.named_styles import NamedStyleList
 from openpyxl.styles.table import TableStyleList
 
 from openpyxl.chartsheet import Chartsheet
-from .defined_name import DefinedName, DefinedNameList
+from .defined_name import DefinedName, DefinedNameDict
 from openpyxl.packaging.core import DocumentProperties
+from openpyxl.packaging.custom import CustomPropertyList
 from openpyxl.packaging.relationship import RelationshipList
 from .child import _WorkbookChild
 from .protection import DocumentSecurity
@@ -62,9 +63,10 @@ class Workbook(object):
         self._sheets = []
         self._pivots = []
         self._active_sheet_index = 0
-        self.defined_names = DefinedNameList()
+        self.defined_names = DefinedNameDict()
         self._external_links = []
         self.properties = DocumentProperties()
+        self.custom_doc_props = CustomPropertyList()
         self.security = DocumentSecurity()
         self.__write_only = write_only
         self.shared_strings = IndexedList()
@@ -230,9 +232,6 @@ class Workbook(object):
     def remove(self, worksheet):
         """Remove `worksheet` from this workbook."""
         idx = self._sheets.index(worksheet)
-        localnames = self.defined_names.localnames(scope=idx)
-        for name in localnames:
-            self.defined_names.delete(name, scope=idx)
         self._sheets.remove(worksheet)
 
 
@@ -326,15 +325,19 @@ class Workbook(object):
         """
         return [s.title for s in self._sheets]
 
+
+    @deprecated("Assign scoped named ranges directly to worksheets or global ones to the workbook. Deprecated in 3.1")
     def create_named_range(self, name, worksheet=None, value=None, scope=None):
-        """Create a new named_range on a worksheet"""
-        defn = DefinedName(name=name, localSheetId=scope)
+        """Create a new named_range on a worksheet
+
+        """
+        defn = DefinedName(name=name)
         if worksheet is not None:
             defn.value = "{0}!{1}".format(quote_sheetname(worksheet.title), value)
         else:
             defn.value = value
 
-        self.defined_names.append(defn)
+        self.defined_names[name] = defn
 
 
     def add_named_style(self, style):
@@ -353,30 +356,6 @@ class Workbook(object):
         return self._named_styles.names
 
 
-    @deprecated("Use workbook.defined_names.definedName")
-    def get_named_ranges(self):
-        """Return all named ranges"""
-        return self.defined_names.definedName
-
-
-    @deprecated("Use workbook.defined_names.append")
-    def add_named_range(self, named_range):
-        """Add an existing named_range to the list of named_ranges."""
-        self.defined_names.append(named_range)
-
-
-    @deprecated("Use workbook.defined_names[name]")
-    def get_named_range(self, name):
-        """Return the range specified by name."""
-        return self.defined_names[name]
-
-
-    @deprecated("Use del workbook.defined_names[name]")
-    def remove_named_range(self, named_range):
-        """Remove a named_range from this workbook."""
-        del self.defined_names[named_range]
-
-
     @property
     def mime_type(self):
         """
@@ -397,7 +376,7 @@ class Workbook(object):
 
         .. warning::
             When creating your workbook using `write_only` set to True,
-            you will only be able to call this function once. Subsequents attempts to
+            you will only be able to call this function once. Subsequent attempts to
             modify or save the file will raise an :class:`openpyxl.shared.exc.WorkbookAlreadySaved` exception.
         """
         if self.read_only:
